Learn R Programming

ugomquantreg (version 1.0.0)

bodyfat: Percentage of body fat data set

Description

The body fat percentage of individuals assisted in a public hospital in Curitiba, Paran<U+00E1>, Brazil.

Usage

data(bodyfat, package = "ugomquantreg")

Arguments

Format

A data-frame with 298 observations and 9 columns:

  • ARMS: arms fat percentage.

  • LEGS: legs fat percentage.

  • BODY: body fat percentage.

  • ANDROID: android fat percentage.

  • GYNECOID: ginecoid fat percentage.

  • AGE: age of individuals.

  • BMI: body mass index.

  • SEX: 1 for female, 2 for male.

  • IPAQ: 0 for IPAQ = sedentary, 1 for IPAQ = insufficiently active and 2 for IPAQ = active.

References

Mazucheli, J., Leiva, V., Alves, B., and Menezes A. F. B., (2021). A new quantile regression for modeling bounded data under a unit Birnbaum-Saunders distribution with applications in medicine and politics. Symmetry, 13(4) 1--21.

Petterle, R. R., Bonat, W. H., Scarpin, C. T., Jonasson, T., and Borba, V. Z. C., (2020). Multivariate quasi-beta regression models for continuous bounded data. The International Journal of Biostatistics, 1--15, (preprint).

Examples

Run this code
# NOT RUN {
data(bodyfat, package = "ugomquantreg")

library(gamlss)

tau <- 0.50
fit.logit <- gamlss(ARMS ~ AGE + I(BMI / 100) + as.factor(SEX) + as.factor(IPAQ), 
data = bodyfat, family = UGOM(mu.link = "logit", sigma.link = "log"))

tau <- 0.50;
fit.probit <- gamlss(ARMS ~ AGE + I(BMI / 100) + as.factor(SEX) + as.factor(IPAQ), 
data = bodyfat, family = UGOM(mu.link = "probit", sigma.link = "log"))


# }

Run the code above in your browser using DataLab